@@ -19,10 +19,7 @@ with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #include "driver.h"
-#ifdef _MSC_VER
-#include <io.h>
-#include <fcntl.h>
-#endif
+#include "nonposix.h"
 
 #define DEFAULT_LINEWIDTH 40
 static int linewidth = DEFAULT_LINEWIDTH;
@@ -854,9 +851,6 @@ int main(int argc, char **argv)
   static char stderr_buf[BUFSIZ];
   setbuf(stderr, stderr_buf);
   int c;
-#ifdef	_MSC_VER
-  _setmode(_fileno(stdout), _O_BINARY);
-#endif
   while ((c = getopt(argc, argv, "F:vw:d")) != EOF)
     switch(c) {
     case 'v':
@@ -885,6 +879,9 @@ int main(int argc, char **argv)
     default:
       assert(0);
     }
+#ifdef SET_BINARY
+  SET_BINARY(fileno(stdout));
+#endif
   if (optind >= argc)
     do_file("-");
   else {
