@@ -31,6 +31,16 @@ TODO
 #include "lbp.h"
 #include "charset.h"
 
+#include "nonposix.h"
+
+#ifdef HAVE_STRNCASECMP
+#ifdef NEED_DECLARATION_STRNCASECMP
+extern "C" {
+  // SunOS's string.h fails to declare this.
+  int strncasecmp(const char *, const char *, int);
+}
+#endif /* NEED_DECLARATION_STRNCASECMP */
+#endif /* HAVE_STRNCASECMP */
 
 static short int papersize = -1,  // papersize
 		 orientation = -1 , // orientation
@@ -50,7 +60,6 @@ private:
   lbp_font(const char *);
 };
 
-
 class lbp_printer : public printer {
 public:
   lbp_printer();
@@ -66,8 +75,8 @@ private:
   void vdmstart();
   void vdmflush(); // the name vdmend was already used in lbp.h
   void setfillmode(int mode);
-  void lbp_printer::polygon( int hpos,int vpos,int np,int *p);
-  char *lbp_printer::font_name(const lbp_font *f, const int siz);
+  void polygon( int hpos,int vpos,int np,int *p);
+  char *font_name(const lbp_font *f, const int siz);
 
   int fill_pattern;
   int fill_mode;
@@ -168,6 +177,9 @@ lbp_printer::lbp_printer()
   cur_symbol_set(0),
   line_thickness(-1)
 {
+#ifdef SET_BINARY
+ SET_BINARY(fileno(stdout));
+#endif
  lbpinit(stdout);
  lbpputs("\033c\033;\033[2&z\033[7 I\033[?32h\033[?33h\033[11h");
  wp54charset(); // Define the new symbol set
@@ -422,8 +434,8 @@ void lbp_printer::draw(int code, int *p, int np, const environment *env)
 			if (vdminited()) vdmlinewidth(line_thickness);
 			// fprintf(stderr,"\nthickness: %d == %d, size %d\n",
 			//         p[0],line_thickness,env->size );
-			break;
 		} // else
+		break;
 
    	case 'l':  // Line
 	     if (np != 2) {
@@ -490,7 +502,7 @@ void lbp_printer::draw(int code, int *p, int np, const environment *env)
 		// We must compensate for that, exchanging the starting and
 		// ending points
 		vdmvarc(env->hpos + p[0],env->vpos+p[1],\
-				int(sqrt( (p[0]*p[0])+(p[1]*p[1]))),\
+				int(sqrt( double((p[0]*p[0])+(p[1]*p[1])))),\
 				p[2],p[3],\
 				(-p[0]),(-p[1]),1,2);	
 		break;
