@@ -19,7 +19,7 @@ with groff; see the file COPYING.  If not, write to the Free Software
 Foundation, 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA. */
 
 #include "eqn.h"
-#include "eqn.tab.h"
+#include "eqn_tab.h"
 #include "stringclass.h"
 #include "ptable.h"
 
